|black| |rtd| |gpl|
|pypi-version| |pypi-python| |pypi-wheel| |deps|

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/python/black
   :alt: Code style: black

.. |rtd| image:: https://readthedocs.org/projects/metalo/badge/?version=latest
   :target: https://metalo.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. |gpl| image:: https://img.shields.io/pypi/l/metalo
   :target: https://gitlab.inria.fr/soliman/metalo/-/raw/main/LICENSE
   :alt: PyPI - License

.. |pypi-version| image:: https://img.shields.io/pypi/v/metalo
   :target: https://pypi.org/project/metalo/
   :alt: PyPI

.. |pypi-python| image:: https://img.shields.io/pypi/pyversions/metalo
   :alt: PyPI - Python Version
   :target: https://pypi.org/project/metalo/

.. |pypi-wheel| image:: https://img.shields.io/pypi/wheel/metalo
   :target: https://pypi.org/project/metalo/
   :alt: PyPI - Wheel

.. |deps| image:: https://img.shields.io/librariesio/release/pypi/metalo
   :target: https://pypi.org/project/metalo/
   :alt: Libraries.io dependency status for latest release

**MetaLo** is a framework for the Metabolic analysis (FBA) of Logical models extracted automatically from detailed mechanistic maps.
See this `published article`_ for more details.

.. _`published article`: http://dx.doi.org/10.1371/journal.pcbi.1010408

Install
=======

Metalo is provided as a Python3 package, you can install it from the `Python package index`_ with ``pip``, ``conda`` or your Python package manager of choice:

.. _`Python package index`: https://pypi.org/project/metalo/

.. code:: bash

   $ python3 -m pip install metalo

Command-line usage
==================

Just follow the instructions::

   $ metalo --help

    usage: metalo [-h] [-v] [-D] [-i INIT] MAP METABOLISM

    Hybrid Framework. Copyright (C) 2023 Sahar.Aghakhani@inria.fr and Sylvain.Soliman@inria.fr GPLv3

    positional arguments:
      MAP                   CellDesigner file containing the mechanistic map
      METABOLISM            MitoCore style metabolic model

    optional arguments:
      -h, --help            show this help message and exit
      -v, --version         show program's version number and exit
      -D, --debug           display some debug information
      -i INIT, --init INIT  CSV file with forced initial values for the Logic model
